@@ -5,8 +5,7 @@ import org.gcube.portlets.widgets.imagepreviewerwidget.shared.Orientation;
 import com.github.gwtbootstrap.client.ui.Image;
 
 /**
- * This class allows to build the image to show within the carousel. Along the image itself, there are 
- * the following other information:
+ * This class allows to build the image to show within the carousel. It contains:
  * <ul>
  * <li>title to show: a title to show in the header of the carousel;</li>
  * <li>tooltip : a tooltip shown on image hover event;</li>
@@ -17,11 +16,6 @@ import com.github.gwtbootstrap.client.ui.Image;
  */
 public class EnhancedImage {
 
-	/**
-	 * The image to show.
-	 */
-	private Image image;
-
 	/**
 	 * Title to show in the header of the carousel.
 	 */
@@ -41,6 +35,11 @@ public class EnhancedImage {
 	 * The orientation
 	 */
 	private Orientation orientation = Orientation.UNDEFINED;
+	
+	/**
+	 * The cached image (once downloaded)
+	 */
+	private Image cachedImage;
 
 	/**
 	 * Build an enhanced image from a url.
@@ -49,40 +48,24 @@ public class EnhancedImage {
 	public EnhancedImage(String imageUrl){
 
 		super();
-		this.image = new Image(imageUrl);
 		this.titleToShow = imageUrl;
 		this.toolTipToShow = imageUrl;
 		this.downloadUrl = imageUrl;
 
 	}
 
-	/**
-	 * Build an enhanced image from another image.
-	 * @param image the image to show
-	 */
-	public EnhancedImage(Image image){
-
-		super();
-		this.image = image;
-		this.titleToShow = image.getUrl();
-		this.toolTipToShow = image.getUrl();
-		this.downloadUrl = image.getUrl();
-
-	}
-
 	/**
 	 * Build an enhanced image from an image but allows to customize the title of the image and its tooltip.
 	 * @param image
 	 * @param titleToShow
 	 * @param toolTipToShow
 	 */
-	public EnhancedImage(Image image, String titleToShow, String toolTipToShow) {
+	public EnhancedImage(String url, String titleToShow, String toolTipToShow) {
 
 		super();
-		this.image = image;
 		this.titleToShow = titleToShow;
 		this.toolTipToShow = toolTipToShow;
-		this.downloadUrl = image.getUrl();
+		this.downloadUrl = url;
 
 	}
 
@@ -93,48 +76,41 @@ public class EnhancedImage {
 	 * @param toolTipToShow
 	 * @param download url
 	 */
-	public EnhancedImage(Image image, String titleToShow, String toolTipToShow, String downloadUrl) {
+	public EnhancedImage(String url, String titleToShow, String toolTipToShow, String downloadUrl) {
 
 		super();
-		this.image = image;
 		this.titleToShow = titleToShow;
 		this.toolTipToShow = toolTipToShow;
-		this.downloadUrl = downloadUrl;
+		this.downloadUrl = url;
 	}
 
-	public Image getImage() {
-
-		return image;
-
-	}
-	public void setImage(Image image) {
-
-		this.image = image;
-
-	}
 	public String getTitleToShow() {
 
 		return titleToShow;
 
 	}
+
 	public void setTitleToShow(String titleToShow) {
 
 		this.titleToShow = titleToShow;
 
 	}
+
 	public String getToolTipToShow() {
 
 		return toolTipToShow;
 
 	}
+
 	public void setToolTipToShow(String toolTipToShow) {
 
 		this.toolTipToShow = toolTipToShow;
 
 	}
+
 	public String getImageUrl(){
 
-		return this.image.getUrl();
+		return this.downloadUrl;
 
 	}
 
@@ -159,14 +135,20 @@ public class EnhancedImage {
 	public void setOrientation(Orientation orientation) {
 		this.orientation = orientation;
 	}
+	
+	public Image getCachedImage() {
+		return cachedImage;
+	}
+
+	public void setCachedImage(Image cachedImage) {
+		this.cachedImage = cachedImage;
+	}
 
-	/* (non-Javadoc)
-	 * @see java.lang.Object#toString()
-	 */
 	@Override
 	public String toString() {
-		return "EnhancedImage [image=" + image + ", titleToShow=" + titleToShow
-				+ ", toolTipToShow=" + toolTipToShow + ", downloadUrl="
-				+ downloadUrl + ", orientation=" + orientation + "]";
+		return "EnhancedImage [titleToShow=" + titleToShow + ", toolTipToShow="
+				+ toolTipToShow + ", downloadUrl=" + downloadUrl
+				+ ", orientation=" + orientation + "]";
 	}
+
 }
